==> haskell-filepattern-0.1.3-98-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filepattern
version:              0.1.3
visibility:           public
id:                   filepattern-0.1.3-CdjwxbG5b1XBAtkH3mebro
key:                  filepattern-0.1.3-CdjwxbG5b1XBAtkH3mebro
license:              BSD-3-Clause
copyright:            Neil Mitchell 2011-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:
    Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>

homepage:             https://github.com/ndmitchell/filepattern#readme
synopsis:             File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:

    * All matching is /O(n)/. Most functions precompute some information given only one argument.

    * See "System.FilePattern" and @?==@ simple matching and semantics.

    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.

    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.

    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.

    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.

category:             Development, FilePath
abi:                  366fb01a3e8f84f56dd50d3e925b211b
exposed:              True
exposed-modules:      System.FilePattern System.FilePattern.Directory
hidden-modules:
    System.FilePattern.Core System.FilePattern.ListBy
    System.FilePattern.Monads System.FilePattern.Step
    System.FilePattern.Tree System.FilePattern.Wildcard

import-dirs:          /usr/lib/ghc-9.2.8/site-local/filepattern-0.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/filepattern-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filepattern
hs-libraries:         HSfilepattern-0.1.3-CdjwxbG5b1XBAtkH3mebro
depends:
    base-4.16.4.0 directory-1.3.6.2 extra-1.7.15-9PmwGQvWkElDwGNWrixqMB
    filepath-1.4.2.2

haddock-interfaces:   /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html:         /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filepattern-0.1.3-142.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filepattern
version:              0.1.3
visibility:           public
id:                   filepattern-0.1.3-HIip3ZEsxwI9gciImIfvS3
key:                  filepattern-0.1.3-HIip3ZEsxwI9gciImIfvS3
license:              BSD-3-Clause
copyright:            Neil Mitchell 2011-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:
    Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>

homepage:             https://github.com/ndmitchell/filepattern#readme
synopsis:             File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:

    * All matching is /O(n)/. Most functions precompute some information given only one argument.

    * See "System.FilePattern" and @?==@ simple matching and semantics.

    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.

    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.

    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.

    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.

category:             Development, FilePath
abi:                  f50e632de303c67e74d13cd112afc737
exposed:              True
exposed-modules:      System.FilePattern System.FilePattern.Directory
hidden-modules:
    System.FilePattern.Core System.FilePattern.ListBy
    System.FilePattern.Monads System.FilePattern.Step
    System.FilePattern.Tree System.FilePattern.Wildcard

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filepattern
hs-libraries:         HSfilepattern-0.1.3-HIip3ZEsxwI9gciImIfvS3
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-CikHmmEQvn83rCDobzYCEG
    filepath-1.4.2.2

haddock-interfaces:   /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html:         /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
